@@ -50,18 +50,18 @@ header <- dashboardHeader(title = "shinyWidgets gallery")
 sidebar <- dashboardSidebar(
   sidebarMenu(
     id = "tabs",
-    menuItem(text = "Overview", tabName = "tabOverview", icon = icon("th")),
+    menuItem(text = "Overview", tabName = "tabOverview", icon = icon("table-cells")),
     menuItem(text = "switchInput", tabName = "tabswitchInput", icon = icon("toggle-on")),
-    menuItem(text = "Pretty Checkboxes & Radios", tabName = "tabPretty", icon = icon("check-circle")),
-    menuItem(text = "Awesome Checkboxes & Radios", tabName = "tabAwesome", icon = icon("check-square")),
+    menuItem(text = "Pretty Checkboxes & Radios", tabName = "tabPretty", icon = icon("circle-check")),
+    menuItem(text = "Awesome Checkboxes & Radios", tabName = "tabAwesome", icon = icon("square-check")),
     menuItem(text = "checkboxGroup Buttons", tabName = "tabcheckButtons", icon = icon("square")),
     menuItem(text = "radio Buttons", tabName = "tabradioButtons", icon = icon("circle")),
     menuItem(text = "materialSwitch", tabName = "tabMaterialSwitch", icon = icon("toggle-off")),
     menuItem(text = "pickerInput", tabName = "tabPickerInput", icon = icon("caret-down")),
-    menuItem(text = "sliderText", tabName = "tabSliderText", icon = icon("sliders-h")),
-    menuItem(text = "progressBar", tabName = "tabProgressBars", icon = icon("tasks")),
+    menuItem(text = "sliderText", tabName = "tabSliderText", icon = icon("sliders")),
+    menuItem(text = "progressBar", tabName = "tabProgressBars", icon = icon("list-check")),
     menuItem(text = "bttn", tabName = "tabBttn", icon = icon("square")),
-    menuItem(text = "dropdowns & sweetalert", tabName = "tabOtherStuff", icon = icon("plus-circle"))
+    menuItem(text = "dropdowns & sweetalert", tabName = "tabOtherStuff", icon = icon("circle-plus"))
   )
 )
 
@@ -180,8 +180,8 @@ body <- dashboardBody(
               args = list(
                 inputId = ID(.shinyWidgetGalleryId), label = "Click search icon to update or hit 'Enter'",
                 placeholder = "A placeholder",
-                btnSearch = icon("search"),
-                btnReset = icon("times"),
+                btnSearch = icon("magnifying-glass"),
+                btnReset = icon("xmark"),
                 width = "100%"
               )
             )
@@ -431,7 +431,7 @@ body <- dashboardBody(
               args = list(inputId = ID(.shinyWidgetGalleryId),
                           label_on = "Yes!", icon_on = icon("check"),
                           status_on = "info", status_off = "warning",
-                          label_off = "No..", icon_off = icon("times"))
+                          label_off = "No..", icon_off = icon("xmark"))
             )
           )
           ,
@@ -483,7 +483,7 @@ body <- dashboardBody(
             .shinyWidgetGalleryFuns$widget_wrapper(
               fun = prettyCheckboxGroup,
               args = list(inputId = ID(.shinyWidgetGalleryId), label = "Choose:", choices = c("Click me !", "Me !", "Or me !"),
-                          icon = icon("check-square"), status = "primary", outline = TRUE, animation = "jelly")
+                          icon = icon("square-check"), status = "primary", outline = TRUE, animation = "jelly")
             )
           )
           ,
@@ -774,7 +774,7 @@ body <- dashboardBody(
               fun = checkboxGroupButtons,
               args = list(
                 inputId = ID(.shinyWidgetGalleryId), label = "Label", choices = c("A", "B", "C", "D"), status = "primary",
-                checkIcon = list(yes = icon("ok", lib = "glyphicon"), no = icon("remove", lib = "glyphicon"))
+                checkIcon = list(yes = icon("ok", lib = "glyphicon"), no = icon("xmark", lib = "glyphicon"))
               )
             )
           )
@@ -926,7 +926,7 @@ body <- dashboardBody(
               fun = radioGroupButtons,
               args = list(
                 inputId = ID(.shinyWidgetGalleryId), label = "Label", choices = c("A", "B", "C", "D"), status = "primary",
-                checkIcon = list(yes = icon("ok", lib = "glyphicon"), no = icon("remove", lib = "glyphicon"))
+                checkIcon = list(yes = icon("ok", lib = "glyphicon"), no = icon("xmark", lib = "glyphicon"))
               )
             )
           )
@@ -1569,7 +1569,7 @@ body <- dashboardBody(
             title = NULL,
             .shinyWidgetGalleryFuns$widget_wrapper(
               fun = actionBttn,
-              args = list(inputId = ID(.shinyWidgetGalleryId), label = "bordered", style = "bordered", color = "success", icon = icon("sliders-h"))
+              args = list(inputId = ID(.shinyWidgetGalleryId), label = "bordered", style = "bordered", color = "success", icon = icon("sliders"))
             ),
             footer = NULL
           ),
@@ -1630,7 +1630,7 @@ body <- dashboardBody(
               selectInput(inputId = 'xcol', label = 'X Variable', choices = names(iris)),
               selectInput(inputId = 'ycol', label = 'Y Variable', choices = names(iris), selected = names(iris)[[2]]),
               sliderInput(inputId = 'clusters', label = 'Cluster count', value = 3, min = 1, max = 9),
-              circle = TRUE, status = "danger", icon = icon("cog"), width = "300px",
+              circle = TRUE, status = "danger", icon = icon("gear"), width = "300px",
               tooltip = tooltipOptions(title = "Click to see inputs !")
             ),
             plotOutput(outputId = 'plot1'),
@@ -1652,7 +1652,7 @@ body <- dashboardBody(
               pickerInput(inputId = 'xcol2', label = 'X Variable', choices = names(iris), options = list(`style` = "btn-info")),
               pickerInput(inputId = 'ycol2', label = 'Y Variable', choices = names(iris), selected = names(iris)[[2]], options = list(`style` = "btn-warning")),
               sliderInput(inputId = 'clusters2', label = 'Cluster count', value = 3, min = 1, max = 9),
-              style = "unite", icon = icon("cog"), status = "danger", width = "300px",
+              style = "unite", icon = icon("gear"), status = "danger", width = "300px",
               animate = animateOptions(enter = animations$fading_entrances$fadeInLeftBig, exit = animations$fading_exits$fadeOutRightBig)
             ),
             plotOutput(outputId = 'plot2'),
